# -*- coding:utf-8 -*-
from cdb import util

def increment_id(name, width, fill="0", skip=1, prefix=""):
    """
    :param prefix: 前缀
    :param name: 在cdb_counter表中的保存的计数器
    :param width: 固定长度
    :param fill: 以什么填充
    :param skip: 起始数字默认位0
    :return:
    """
    result = "{}{}".format(prefix, str(util.nextval(name)+skip).rjust(int(width), fill))
    return result



# -*- coding:utf-8 -*--
import setuptools


with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="cdb_euci",
    version="0.0.2",
    author="moda",
    author_email="2586935358@qq.com",
    description="CDB Utils By Euci",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    install_requires=[],
    license='MIT License',
    packages=setuptools.find_packages(),
    platforms=["all"],
    classifiers=[
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        'Natural Language :: Chinese (Simplified)',
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Topic :: Software Development :: Libraries"
    ],
)
